pub struct MemoryRegion {
pub host_addr: u64,
pub vm_addr: u64,
pub len: u64,
pub vm_gap_shift: u8,
pub is_writable: bool,
}Expand description
Memory region for bounds checking and address translation
Fields
host_addr: u64start host address
vm_addr: u64start virtual address
len: u64Length in bytes
vm_gap_shift: u8Size of regular gaps as bit shift (63 means this region is continuous)
is_writable: boolIs also writable (otherwise it is readonly)
Implementations
Sourceimpl MemoryRegion
impl MemoryRegion
Sourcepub fn new_from_slice(
slice: &[u8],
vm_addr: u64,
vm_gap_size: u64,
is_writable: bool,
) -> Self
pub fn new_from_slice( slice: &[u8], vm_addr: u64, vm_gap_size: u64, is_writable: bool, ) -> Self
Creates a new MemoryRegion structure from a slice
Sourcepub fn vm_to_host<E: UserDefinedError>(
&self,
vm_addr: u64,
len: u64,
) -> Result<u64, EbpfError<E>>
pub fn vm_to_host<E: UserDefinedError>( &self, vm_addr: u64, len: u64, ) -> Result<u64, EbpfError<E>>
Convert a virtual machine address into a host address Does not perform a lower bounds check, as that is already done by the binary search in MemoryMapping::map()